@@ -196,6 +196,7 @@ types: list[str] = [
     "AWS::Cognito::IdentityPoolPrincipalTag",
     "AWS::Cognito::IdentityPoolRoleAttachment",
     "AWS::Cognito::LogDeliveryConfiguration",
+    "AWS::Cognito::ManagedLoginBranding",
     "AWS::Cognito::UserPool",
     "AWS::Cognito::UserPoolClient",
     "AWS::Cognito::UserPoolDomain",
@@ -523,12 +524,14 @@ types: list[str] = [
     "AWS::InspectorV2::CisScanConfiguration",
     "AWS::InspectorV2::Filter",
     "AWS::InternetMonitor::Monitor",
+    "AWS::Invoicing::InvoiceUnit",
     "AWS::IoT::AccountAuditConfiguration",
     "AWS::IoT::Authorizer",
     "AWS::IoT::BillingGroup",
     "AWS::IoT::CACertificate",
     "AWS::IoT::Certificate",
     "AWS::IoT::CertificateProvider",
+    "AWS::IoT::Command",
     "AWS::IoT::CustomMetric",
     "AWS::IoT::Dimension",
     "AWS::IoT::DomainConfiguration",
@@ -601,6 +604,7 @@ types: list[str] = [
     "AWS::Logs::ResourcePolicy",
     "AWS::Logs::SubscriptionFilter",
     "AWS::M2::Application",
+    "AWS::M2::Deployment",
     "AWS::M2::Environment",
     "AWS::MSK::BatchScramSecret",
     "AWS::MSK::Cluster",
@@ -637,6 +641,7 @@ types: list[str] = [
     "AWS::MediaPackageV2::OriginEndpointPolicy",
     "AWS::MemoryDB::ACL",
     "AWS::MemoryDB::Cluster",
+    "AWS::MemoryDB::MultiRegionCluster",
     "AWS::MemoryDB::ParameterGroup",
     "AWS::MemoryDB::SubnetGroup",
     "AWS::MemoryDB::User",
@@ -914,10 +919,13 @@ types: list[str] = [
     "AWS::VpcLattice::AccessLogSubscription",
     "AWS::VpcLattice::AuthPolicy",
     "AWS::VpcLattice::Listener",
+    "AWS::VpcLattice::ResourceConfiguration",
+    "AWS::VpcLattice::ResourceGateway",
     "AWS::VpcLattice::ResourcePolicy",
     "AWS::VpcLattice::Rule",
     "AWS::VpcLattice::Service",
     "AWS::VpcLattice::ServiceNetwork",
+    "AWS::VpcLattice::ServiceNetworkResourceAssociation",
     "AWS::VpcLattice::ServiceNetworkServiceAssociation",
     "AWS::VpcLattice::ServiceNetworkVpcAssociation",
     "AWS::VpcLattice::TargetGroup",
@@ -1095,13 +1103,11 @@ cached: list[str] = [
     "aws-cloudformation-resourceversion.json",
     "aws-cloudformation-stack.json",
     "aws-cloudformation-stackset.json",
-    "aws-cloudformation-typeactivation.json",
     "aws-cloudformation-waitcondition.json",
     "aws-cloudformation-waitconditionhandle.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
-    "aws-cloudfront-distribution.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-keyvaluestore.json",
@@ -1143,6 +1149,7 @@ cached: list[str] = [
     "aws-cognito-identitypoolprincipaltag.json",
     "aws-cognito-identitypoolroleattachment.json",
     "aws-cognito-logdeliveryconfiguration.json",
+    "aws-cognito-managedloginbranding.json",
     "aws-cognito-userpool.json",
     "aws-cognito-userpoolclient.json",
     "aws-cognito-userpooldomain.json",
@@ -1213,7 +1220,6 @@ cached: list[str] = [
     "aws-ec2-clientvpnendpoint.json",
     "aws-ec2-clientvpnroute.json",
     "aws-ec2-clientvpntargetnetworkassociation.json",
-    "aws-ec2-customergateway.json",
     "aws-ec2-dhcpoptions.json",
     "aws-ec2-ec2fleet.json",
     "aws-ec2-egressonlyinternetgateway.json",
@@ -1455,12 +1461,14 @@ cached: list[str] = [
     "aws-inspectorv2-cisscanconfiguration.json",
     "aws-inspectorv2-filter.json",
     "aws-internetmonitor-monitor.json",
+    "aws-invoicing-invoiceunit.json",
     "aws-iot-accountauditconfiguration.json",
     "aws-iot-authorizer.json",
     "aws-iot-billinggroup.json",
     "aws-iot-cacertificate.json",
     "aws-iot-certificate.json",
     "aws-iot-certificateprovider.json",
+    "aws-iot-command.json",
     "aws-iot-custommetric.json",
     "aws-iot-dimension.json",
     "aws-iot-domainconfiguration.json",
@@ -1521,14 +1529,10 @@ cached: list[str] = [
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-loganomalydetector.json",
-    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
-    "aws-logs-metricfilter.json",
-    "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
-    "aws-logs-subscriptionfilter.json",
     "aws-m2-application.json",
-    "aws-m2-environment.json",
+    "aws-m2-deployment.json",
     "aws-macie-allowlist.json",
     "aws-macie-customdataidentifier.json",
     "aws-macie-findingsfilter.json",
@@ -1556,7 +1560,7 @@ cached: list[str] = [
     "aws-mediapackagev2-originendpoint.json",
     "aws-mediapackagev2-originendpointpolicy.json",
     "aws-memorydb-acl.json",
-    "aws-memorydb-cluster.json",
+    "aws-memorydb-multiregioncluster.json",
     "aws-memorydb-parametergroup.json",
     "aws-memorydb-subnetgroup.json",
     "aws-memorydb-user.json",
@@ -1564,7 +1568,6 @@ cached: list[str] = [
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
-    "aws-msk-replicator.json",
     "aws-msk-vpcconnection.json",
     "aws-mwaa-environment.json",
     "aws-neptune-dbcluster.json",
@@ -1613,7 +1616,6 @@ cached: list[str] = [
     "aws-pcaconnectorscep-connector.json",
     "aws-pipes-pipe.json",
     "aws-ram-permission.json",
-    "aws-ram-resourceshare.json",
     "aws-rbin-rule.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
@@ -1640,7 +1642,6 @@ cached: list[str] = [
     "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
-    "aws-redshiftserverless-workgroup.json",
     "aws-refactorspaces-application.json",
     "aws-refactorspaces-environment.json",
     "aws-refactorspaces-route.json",
@@ -1696,6 +1697,7 @@ cached: list[str] = [
     "aws-s3outposts-endpoint.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
+    "aws-sagemaker-cluster.json",
     "aws-sagemaker-coderepository.json",
     "aws-sagemaker-dataqualityjobdefinition.json",
     "aws-sagemaker-domain.json",
@@ -1767,7 +1769,6 @@ cached: list[str] = [
     "aws-servicediscovery-instance.json",
     "aws-servicediscovery-privatednsnamespace.json",
     "aws-servicediscovery-publicdnsnamespace.json",
-    "aws-servicediscovery-service.json",
     "aws-ses-configurationset.json",
     "aws-ses-configurationseteventdestination.json",
     "aws-ses-contactlist.json",
@@ -1833,10 +1834,13 @@ cached: list[str] = [
     "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
     "aws-vpclattice-listener.json",
+    "aws-vpclattice-resourceconfiguration.json",
+    "aws-vpclattice-resourcegateway.json",
     "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
     "aws-vpclattice-servicenetwork.json",
+    "aws-vpclattice-servicenetworkresourceassociation.json",
     "aws-vpclattice-servicenetworkserviceassociation.json",
     "aws-vpclattice-servicenetworkvpcassociation.json",
     "aws-vpclattice-targetgroup.json",
